==> jc-1.4.0.tar.gz: polyglot/ext/param/ExtensionInfo.h <==
// public abstract class polyglot.ext.param.ExtensionInfo

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class b87d6875b316a8f polyglot_ext_jl_ExtensionInfo
// @dep_class ccbe8f1f79673639 polyglot_ext_param_ExtensionInfo
// @dep_class b1e2e9278240b294 polyglot_frontend_AbstractExtensionInfo

// header file dependencies
// @dep_header polyglot_ext_jl_ExtensionInfo

#include "polyglot/ext/jl/ExtensionInfo.h"

#ifndef _JC_polyglot_ext_param_ExtensionInfo_H_
#define _JC_polyglot_ext_param_ExtensionInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_ExtensionInfo$sub_refs	_jc_polyglot_ext_param_ExtensionInfo$sub_refs;
typedef struct _jc_polyglot_ext_param_ExtensionInfo$sub_nonrefs	_jc_polyglot_ext_param_ExtensionInfo$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_ExtensionInfo$refs	_jc_polyglot_ext_param_ExtensionInfo$refs;
typedef struct _jc_polyglot_ext_param_ExtensionInfo$nonrefs	_jc_polyglot_ext_param_ExtensionInfo$nonrefs;
typedef struct _jc_polyglot_ext_param_ExtensionInfo$object	_jc_polyglot_ext_param_ExtensionInfo$object;

typedef const struct _jc_polyglot_ext_param_ExtensionInfo$vmethods	_jc_polyglot_ext_param_ExtensionInfo$vmethods;
typedef const struct _jc_polyglot_ext_param_ExtensionInfo$vtable	_jc_polyglot_ext_param_ExtensionInfo$vtable;
typedef const struct _jc_polyglot_ext_param_ExtensionInfo$vtype	_jc_polyglot_ext_param_ExtensionInfo$vtype;

// Constructors
extern void _jc_polyglot_ext_param_ExtensionInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_param_ExtensionInfo$object *);

// Static methods
extern void _jc_polyglot_ext_param_ExtensionInfo$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_polyglot_ext_param_ExtensionInfo$vmethods {
};

// Vtable
struct _jc_polyglot_ext_param_ExtensionInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractExtensionInfo$vmethods	polyglot_frontend_AbstractExtensionInfo;
	_jc_polyglot_ext_jl_ExtensionInfo$vmethods	polyglot_ext_jl_ExtensionInfo;
	_jc_polyglot_ext_param_ExtensionInfo$vmethods	polyglot_ext_param_ExtensionInfo;
};

// Vtype
struct _jc_polyglot_ext_param_ExtensionInfo$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_ExtensionInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_ExtensionInfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_ExtensionInfo$refs {
    _jc_polyglot_ext_param_ExtensionInfo$sub_refs	polyglot_ext_param_ExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_refs	polyglot_ext_jl_ExtensionInfo;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_refs	polyglot_frontend_AbstractExtensionInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_ExtensionInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_ExtensionInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_nonrefs	polyglot_frontend_AbstractExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_nonrefs	polyglot_ext_jl_ExtensionInfo;
    _jc_polyglot_ext_param_ExtensionInfo$sub_nonrefs	polyglot_ext_param_ExtensionInfo;
};

// Object instance structure
struct _jc_polyglot_ext_param_ExtensionInfo$object {
	_jc_polyglot_ext_param_ExtensionInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_ExtensionInfo$vtype	*vtype;
	_jc_polyglot_ext_param_ExtensionInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_ExtensionInfo$vtype _jc_polyglot_ext_param_ExtensionInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_ExtensionInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_ExtensionInfo$class_object;

#endif	/* _JC_polyglot_ext_param_ExtensionInfo_H_ */

==> jc-1.4.6.tar.gz: polyglot/ext/param/ExtensionInfo.h <==
// public abstract class polyglot.ext.param.ExtensionInfo

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class b87d6875b316a8f polyglot_ext_jl_ExtensionInfo
// @dep_class ccbe8f1f79673639 polyglot_ext_param_ExtensionInfo
// @dep_class b1e2e9278240b294 polyglot_frontend_AbstractExtensionInfo

// header file dependencies
// @dep_header polyglot_ext_jl_ExtensionInfo

#include "polyglot/ext/jl/ExtensionInfo.h"

#ifndef _JC_polyglot_ext_param_ExtensionInfo_H_
#define _JC_polyglot_ext_param_ExtensionInfo_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_polyglot_ext_param_ExtensionInfo$sub_refs	_jc_polyglot_ext_param_ExtensionInfo$sub_refs;
typedef struct _jc_polyglot_ext_param_ExtensionInfo$sub_nonrefs	_jc_polyglot_ext_param_ExtensionInfo$sub_nonrefs;
typedef struct _jc_polyglot_ext_param_ExtensionInfo$refs	_jc_polyglot_ext_param_ExtensionInfo$refs;
typedef struct _jc_polyglot_ext_param_ExtensionInfo$nonrefs	_jc_polyglot_ext_param_ExtensionInfo$nonrefs;
typedef struct _jc_polyglot_ext_param_ExtensionInfo$object	_jc_polyglot_ext_param_ExtensionInfo$object;

typedef const struct _jc_polyglot_ext_param_ExtensionInfo$vmethods	_jc_polyglot_ext_param_ExtensionInfo$vmethods;
typedef const struct _jc_polyglot_ext_param_ExtensionInfo$vtable	_jc_polyglot_ext_param_ExtensionInfo$vtable;
typedef const struct _jc_polyglot_ext_param_ExtensionInfo$vtype	_jc_polyglot_ext_param_ExtensionInfo$vtype;

// Constructors
extern void _jc_polyglot_ext_param_ExtensionInfo$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_polyglot_ext_param_ExtensionInfo$object *) _JC_JCNI_ATTR;

// Static methods
extern void _jc_polyglot_ext_param_ExtensionInfo$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_polyglot_ext_param_ExtensionInfo$vmethods {
};

// Vtable
struct _jc_polyglot_ext_param_ExtensionInfo$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_polyglot_frontend_AbstractExtensionInfo$vmethods	polyglot_frontend_AbstractExtensionInfo;
	_jc_polyglot_ext_jl_ExtensionInfo$vmethods	polyglot_ext_jl_ExtensionInfo;
	_jc_polyglot_ext_param_ExtensionInfo$vmethods	polyglot_ext_param_ExtensionInfo;
};

// Vtype
struct _jc_polyglot_ext_param_ExtensionInfo$vtype {
	_jc_type			type;
	_jc_polyglot_ext_param_ExtensionInfo$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_polyglot_ext_param_ExtensionInfo$sub_refs {
};

// Reference instance fields (object)
struct _jc_polyglot_ext_param_ExtensionInfo$refs {
    _jc_polyglot_ext_param_ExtensionInfo$sub_refs	polyglot_ext_param_ExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_refs	polyglot_ext_jl_ExtensionInfo;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_refs	polyglot_frontend_AbstractExtensionInfo;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_polyglot_ext_param_ExtensionInfo$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_polyglot_ext_param_ExtensionInfo$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_polyglot_frontend_AbstractExtensionInfo$sub_nonrefs	polyglot_frontend_AbstractExtensionInfo;
    _jc_polyglot_ext_jl_ExtensionInfo$sub_nonrefs	polyglot_ext_jl_ExtensionInfo;
    _jc_polyglot_ext_param_ExtensionInfo$sub_nonrefs	polyglot_ext_param_ExtensionInfo;
};

// Object instance structure
struct _jc_polyglot_ext_param_ExtensionInfo$object {
	_jc_polyglot_ext_param_ExtensionInfo$refs	refs[0];
	_jc_word		lockword;
	_jc_polyglot_ext_param_ExtensionInfo$vtype	*vtype;
	_jc_polyglot_ext_param_ExtensionInfo$nonrefs	nonrefs;
};

// Type structure
extern _jc_polyglot_ext_param_ExtensionInfo$vtype _jc_polyglot_ext_param_ExtensionInfo$type;

// Array types class info structures
_JC_DECL_ARRAYS(polyglot_ext_param_ExtensionInfo, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_polyglot_ext_param_ExtensionInfo$class_object;

#endif	/* _JC_polyglot_ext_param_ExtensionInfo_H_ */
